@@ -17,10 +17,10 @@ from .misc import year_blocks, day_blocks
 from .parsers import parse_prices, parse_loads, parse_generation, \
     parse_installed_capacity_per_plant, parse_crossborder_flows, \
     parse_unavailabilities, parse_contracted_reserve, parse_imbalance_prices_zip, \
-    parse_netpositions
+    parse_netpositions, parse_procured_balancing_capacity
 
 __title__ = "entsoe-py"
-__version__ = "0.3.4"
+__version__ = "0.3.6"
 __author__ = "EnergieID.be"
 __license__ = "MIT"
 
@@ -440,13 +440,17 @@ class EntsoeRawClient:
 
     def query_scheduled_exchanges(
             self, country_code_from: Union[Area, str],
-            country_code_to: Union[Area, str], start: pd.Timestamp,
-            end: pd.Timestamp, **kwargs) -> str:
+            country_code_to: Union[Area, str],
+            start: pd.Timestamp,
+            end: pd.Timestamp,
+            dayahead: bool = False,
+            **kwargs) -> str:
         """
         Parameters
         ----------
         country_code_from : Area|str
         country_code_to : Area|str
+        dayahead : bool
         start : pd.Timestamp
         end : pd.Timestamp
 
@@ -454,10 +458,14 @@ class EntsoeRawClient:
         -------
         str
         """
+        if dayahead:
+            contract_marketagreement_type = "A01"
+        else:
+            contract_marketagreement_type = "A05"
         return self._query_crossborder(
             country_code_from=country_code_from,
             country_code_to=country_code_to, start=start, end=end,
-            doctype="A09", contract_marketagreement_type="A05")
+            doctype="A09", contract_marketagreement_type=contract_marketagreement_type)
 
     def query_net_transfer_capacity_dayahead(
             self, country_code_from: Union[Area, str],
@@ -634,6 +642,40 @@ class EntsoeRawClient:
         response = self._base_request(params=params, start=start, end=end)
         return response.content
 
+    def query_procured_balancing_capacity(
+            self, country_code: Union[Area, str], start: pd.Timestamp,
+            end: pd.Timestamp, process_type: str,
+            type_marketagreement_type: Optional[str] = None) -> bytes:
+        """
+        Activated Balancing Energy [17.1.E]
+        Parameters
+        ----------
+        country_code : Area|str
+        start : pd.Timestamp
+        end : pd.Timestamp
+        process_type : str
+            A51 ... aFRR; A47 ... mFRR
+        type_marketagreement_type : str
+            type of contract (see mappings.MARKETAGREEMENTTYPE)
+
+        Returns
+        -------
+        bytes
+        """
+        if process_type not in ['A51', 'A47']:
+            raise ValueError('processType allowed values: A51, A47')
+
+        area = lookup_area(country_code)
+        params = {
+            'documentType': 'A15',
+            'area_Domain': area.code,
+            'processType': process_type
+        }
+        if type_marketagreement_type:
+            params.update({'type_MarketAgreement.Type': type_marketagreement_type})
+        response = self._base_request(params=params, start=start, end=end)
+        return response.content
+
     def query_activated_balancing_energy(
             self, country_code: Union[Area, str], start: pd.Timestamp,
             end: pd.Timestamp, business_type: str, 
@@ -1215,8 +1257,11 @@ class EntsoePandasClient(EntsoeRawClient):
     @year_limited
     def query_scheduled_exchanges(
             self, country_code_from: Union[Area, str],
-            country_code_to: Union[Area, str], start: pd.Timestamp,
-            end: pd.Timestamp, **kwargs) -> pd.Series:
+            country_code_to: Union[Area, str],
+            start: pd.Timestamp,
+            end: pd.Timestamp,
+            dayahead: bool = False,
+            **kwargs) -> pd.Series:
         """
         Note: Result will be in the timezone of the origin country
 
@@ -1224,6 +1269,7 @@ class EntsoePandasClient(EntsoeRawClient):
         ----------
         country_code_from : Area|str
         country_code_to : Area|str
+        dayahead : bool
         start : pd.Timestamp
         end : pd.Timestamp
 
@@ -1236,6 +1282,7 @@ class EntsoePandasClient(EntsoeRawClient):
         text = super(EntsoePandasClient, self).query_scheduled_exchanges(
             country_code_from=area_from,
             country_code_to=area_to,
+            dayahead=dayahead,
             start=start,
             end=end)
         ts = parse_crossborder_flows(text)
@@ -1424,6 +1471,37 @@ class EntsoePandasClient(EntsoeRawClient):
         df = df.truncate(before=start, after=end)
         return df
 
+    @year_limited
+    @paginated
+    def query_procured_balancing_capacity(
+            self, country_code: Union[Area, str], start: pd.Timestamp,
+            end: pd.Timestamp, process_type: str,
+            type_marketagreement_type: Optional[str] = None) -> bytes:
+        """
+        Activated Balancing Energy [17.1.E]
+        Parameters
+        ----------
+        country_code : Area|str
+        start : pd.Timestamp
+        end : pd.Timestamp
+        process_type : str
+            A51 ... aFRR; A47 ... mFRR
+        type_marketagreement_type : str
+            type of contract (see mappings.MARKETAGREEMENTTYPE)
+
+        Returns
+        -------
+        pd.DataFrame
+        """
+        area = lookup_area(country_code)
+        text = super(EntsoePandasClient, self).query_procured_balancing_capacity(
+            country_code=area, start=start, end=end,
+            process_type=process_type, type_marketagreement_type=type_marketagreement_type)
+        df = parse_procured_balancing_capacity(text, area.tz)
+        df = df.tz_convert(area.tz)
+        df = df.truncate(before=start, after=end)
+        return df
+
     @year_limited
     def query_activated_balancing_energy(
             self, country_code: Union[Area, str], start: pd.Timestamp,
@@ -1659,6 +1737,7 @@ class EntsoePandasClient(EntsoeRawClient):
     def query_generation_per_plant(
             self, country_code: Union[Area, str], start: pd.Timestamp,
             end: pd.Timestamp, psr_type: Optional[str] = None,
+            include_eic: bool = False,
             nett: bool = False, **kwargs) -> pd.DataFrame:
         """
         Parameters
@@ -1670,6 +1749,8 @@ class EntsoePandasClient(EntsoeRawClient):
             filter on a single psr type
         nett : bool
             condense generation and consumption into a nett number
+        include_eic: bool
+            if True also include the eic code in the output
 
         Returns
         -------
@@ -1678,7 +1759,7 @@ class EntsoePandasClient(EntsoeRawClient):
         area = lookup_area(country_code)
         text = super(EntsoePandasClient, self).query_generation_per_plant(
             country_code=area, start=start, end=end, psr_type=psr_type)
-        df = parse_generation(text, per_plant=True)
+        df = parse_generation(text, per_plant=True, include_eic=include_eic)
         df.columns = df.columns.set_levels(df.columns.levels[0].str.encode('latin-1').str.decode('utf-8'), level=0)
         df = df.tz_convert(area.tz)
         # Truncation will fail if data is not sorted along the index in rare
