@@ -77,6 +77,7 @@ class Area(enum.Enum):
     IE =            '10YIE-1001A00010', 'Ireland, EirGrid CA',                          'Europe/Dublin',
     IT =            '10YIT-GRTN-----B', 'Italy, IT CA / MBA',                           'Europe/Rome',
     IT_SACO_AC =    '10Y1001A1001A885', 'Italy_Saco_AC',                                'Europe/Rome',
+    IT_CALA =   '10Y1001C--00096J', 'IT-Calabria BZ',                                'Europe/Rome',
     IT_SACO_DC =    '10Y1001A1001A893', 'Italy_Saco_DC',                                'Europe/Rome',
     IT_BRNN =       '10Y1001A1001A699', 'IT-Brindisi BZ',                               'Europe/Rome',
     IT_CNOR =       '10Y1001A1001A70O', 'IT-Centre-North BZ',                           'Europe/Rome',
@@ -303,12 +304,13 @@ NEIGHBOURS = {
     'NO_3': ['NO_4', 'NO_5', 'SE_2'],
     'IT': ['AT', 'FR', 'GR', 'MT', 'ME', 'SI', 'CH'],
     'IT_BRNN': ['GR', 'IT_SUD'],
-    'IT_SUD': ['IT_BRNN', 'IT_CSUD', 'IT_FOGN', 'IT_ROSN'],
+    'IT_SUD': ['IT_BRNN', 'IT_CSUD', 'IT_FOGN', 'IT_ROSN', 'IT_CALA'],
     'IT_FOGN': ['IT_SUD'],
     'IT_ROSN': ['IT_SICI', 'IT_SUD'],
     'IT_CSUD': ['IT_CNOR', 'IT_SARD', 'IT_SUD'],
     'IT_CNOR': ['IT_NORD', 'IT_CSUD', 'IT_SARD'],
     'IT_SARD': ['IT_CNOR', 'IT_CSUD'],
-    'IT_SICI': ['IT_ROSN', 'MT'],
+    'IT_SICI': ['IT_CALA', 'IT_ROSN', 'MT'],
+    'IT_CALA': ['IT_SICI', 'IT_SUD'],
     'MT': ['IT_SICI']
 }
