@@ -38,7 +38,7 @@ def parse_prices(xml_text):
     -------
     pd.Series
     """
-    series = pd.Series()
+    series = pd.Series(dtype = 'object')
     for soup in _extract_timeseries(xml_text):
         series = series.append(_parse_price_timeseries(soup))
     series = series.sort_index()
@@ -56,7 +56,7 @@ def parse_netpositions(xml_text):
     -------
     pd.Series
     """
-    series = pd.Series()
+    series = pd.Series(dtype = 'object')
     for soup in _extract_timeseries(xml_text):
         series = series.append(_parse_netposition_timeseries(soup))
     series = series.sort_index()
@@ -73,7 +73,7 @@ def parse_loads(xml_text):
     -------
     pd.Series
     """
-    series = pd.Series()
+    series = pd.Series(dtype = 'object')
     for soup in _extract_timeseries(xml_text):
         series = series.append(_parse_load_timeseries(soup))
     series = series.sort_index()
@@ -83,6 +83,7 @@ def parse_loads(xml_text):
 def parse_generation(
         xml_text: str,
         per_plant: bool = False,
+        include_eic: bool = False,
         nett: bool = False) -> Union[pd.DataFrame, pd.Series]:
     """
     Parameters
@@ -93,6 +94,8 @@ def parse_generation(
     nett : bool
         If you want to condense generation and consumption of a plant into a
         nett number
+    include_eic: bool
+        If you want to include the eic code of a plan in the output
 
     Returns
     -------
@@ -100,7 +103,7 @@ def parse_generation(
     """
     all_series = dict()
     for soup in _extract_timeseries(xml_text):
-        ts = _parse_generation_timeseries(soup, per_plant=per_plant)
+        ts = _parse_generation_timeseries(soup, per_plant=per_plant, include_eic=include_eic)
 
         # check if we already have a series of this name
         series = all_series.get(ts.name)
@@ -204,7 +207,7 @@ def parse_crossborder_flows(xml_text):
     -------
     pd.Series
     """
-    series = pd.Series()
+    series = pd.Series(dtype = 'object')
     for soup in _extract_timeseries(xml_text):
         series = series.append(_parse_crossborder_flows_timeseries(soup))
     series = series.sort_index()
@@ -230,6 +233,65 @@ def parse_imbalance_prices(xml_text):
     return df
 
 
+def parse_procured_balancing_capacity(xml_text, tz):
+    """
+    Parameters
+    ----------
+    xml_text : str
+    tz: str
+
+    Returns
+    -------
+    pd.DataFrame
+    """
+    timeseries_blocks = _extract_timeseries(xml_text)
+    frames = (_parse_procured_balancing_capacity(soup, tz)
+              for soup in timeseries_blocks)
+    df = pd.concat(frames, axis=1)
+
+    df.sort_index(axis=0, inplace=True)
+    df.sort_index(axis=1, inplace=True)
+    return df
+
+
+def _parse_procured_balancing_capacity(soup, tz):
+    """
+    Parameters
+    ----------
+    soup : bs4.element.tag
+    tz: str
+
+    Returns
+    -------
+    pd.DataFrame
+    """
+    direction = {
+        'A01': 'Up',
+        'A02': 'Down'
+    }
+
+    flow_direction = direction[soup.find('flowdirection.direction').text]
+    period = soup.find('period')
+    start = pd.to_datetime(period.find('timeinterval').find('start').text)
+    end = pd.to_datetime(period.find('timeinterval').find('end').text)
+    resolution = _resolution_to_timedelta(period.find('resolution').text)
+    tx = pd.date_range(start=start, end=end, freq=resolution, closed='left')
+    points = period.find_all('point')
+    df = pd.DataFrame(index=tx, columns=['Price', 'Volume'])
+
+    for dt, point in zip(tx, points):
+        df.loc[dt, 'Price'] = float(point.find('procurement_price.amount').text)
+        df.loc[dt, 'Volume'] = float(point.find('quantity').text)
+
+    mr_id = int(soup.find('mrid').text)
+    df.columns = pd.MultiIndex.from_product(
+        [[flow_direction], [mr_id], df.columns],
+        names=('direction', 'mrid', 'unit')
+    )
+
+    return df
+
+
 def parse_contracted_reserve(xml_text, tz, label):
     """
     Parameters
@@ -428,7 +490,7 @@ def _parse_load_timeseries(soup):
     return series
 
 
-def _parse_generation_timeseries(soup, per_plant: bool = False) -> pd.Series:
+def _parse_generation_timeseries(soup, per_plant: bool = False, include_eic: bool = False) -> pd.Series:
     """
     Works for generation by type, generation forecast, and wind and solar
     forecast
@@ -481,6 +543,10 @@ def _parse_generation_timeseries(soup, per_plant: bool = False) -> pd.Series:
     if per_plant:
         plantname = soup.find('name').text
         name.append(plantname)
+        if include_eic:
+            eic = soup.find("mrid", codingscheme="A01").text
+            name.insert(0, eic)
+
 
     if len(name) == 1:
         series.name = name[0]
